@@ -64,7 +64,6 @@
     clippy::option_option,
     clippy::path_buf_push_overwrite,
     clippy::ptr_as_ptr,
-    clippy::pub_enum_variant_names,
     clippy::ref_option_ref,
     clippy::rest_pat_in_fully_bound_structs,
     clippy::same_functions_in_if_condition,
@@ -79,7 +78,6 @@
     clippy::unused_self,
     clippy::useless_transmute,
     clippy::verbose_file_reads,
-    clippy::wrong_pub_self_convention,
     clippy::zero_sized_map_values,
     future_incompatible,
     nonstandard_style,
